@@ -22,10 +22,10 @@ Licensed under the MIT license, see the LICENSE file.
 
 RELEASE = False
 
-__version_info__ = ('0', '3', 'dev')
+__version_info__ = ('0', '4', 'dev')
 
 
 __version__ = '.'.join(__version_info__)
 __author__ = 'LUMC, Jeroen F.J. Laros'
-__contact__ = 'j.f.j.laros@@lumc.nl'
+__contact__ = 'j.f.j.laros@lumc.nl'
 __homepage__ = 'https://git.lumc.nl/j.f.j.laros/barcode'
